%r=filmSpectrumTE(r, P)
%----------------------
%
%Computes the electromagnetic spectrum through an array of slits in
%a metal layer. See 'filmTransmissionTE' for a description of the
%model geometry.
%
%The incident plane wave has an intensity of 1W/m^2.
%
%Input:
% r      Structure (see 'filmTransmissionTE')
% P      Compute up to |kx|=P*k {all}
%
%Output:
% r      Structure completed with
%  .P       Used limit for kx
%  .gr      kx/k0 of the reflection
%  .gt      kx/k0 of the transmission
%  .Fr      Reflection coefficient
%  .Ft      Transmission coefficient
%
function r=filmSpectrumTE(r, P)
if ~nargin | isempty(r) | ~isstruct(r)
   help filmSpectrumTE
   return;
end
if nargin < 2 | length(P) ~= 1
   P=[];
else
   P=abs(P);
end
if ~isfield(r,'um')
   r=filmTransmissionTE(r,P);
end
r.P=P;
r.gr=r.gn;
r.gt=r.gn;
r.Fr=r.Cm.*r.Rm*r.um.'*exp(i*r.k0*r.xm*(r.g0-r.gn))/length(r.xm);
r.Ft=r.Cm.*r.Tm*r.um.'*exp(i*r.k0*r.xm*(r.g0-r.gn))/length(r.xm);
