%[gn,Fn]=fourierCte(C0,g0,Cm,gm,k0,wx,px,P)
%------------------------------------------
%
%Computes the field difference at the slit boundary and
%returns the coefficients of the Fourier expansion.
%
%Input:
% C0     Coefficient at the metal layer
% g0     kx/k0 of the incident wave
% Cm     Modal coefficients at the slit
% gm     kx/k0 of the TE hole modes
% k0     Wavevector in free space [rad/m]
% wx     Width of the slits [m]
% px     Distance between the slits [m]
% P      Compute up to |kx|=P*k0 {all}
%
%Output:
% gn     kx/k0 of the diffracted waves
% Fn     Fourier coefficients
%
function [gn,Fn]=fourierCte(C0,g0,Cm,gm,k0,wx,px,P)
t=max(100,10*length(gm));
t=2^ceil(log2(px/wx*t));
s=floor(t*wx/2/px);
x=px/t*(-s:s);
f=Cm*sin(k0*gm'*(x+wx/2))-C0*exp(i*k0*g0*x);
gn=[-t/2:t/2-1]*2*pi/px/k0;
Fn=fftshift(fft(f,t)/t);
if length(P)
   t=find(abs(gn) < P);
   gn=gn(t);
   Fn=Fn(t);
end
