%Cm=slitCte(g0,gm,k0,wx)
%-----------------------
%
%Computes the coupling coefficients representing a plane TE
%wave as a series of cosine TE slit modes.
%
%Reconstruction formula: f=Cm*sin(k0*gm'*(x+wx/2))
%
%Input:
% g0     kx/k0 of the incident wave
% gm     kx/k0 of the TE slit modes
% k0     Wavevector in free space [rad/m]
% wx     Width of the slits [m]
%
%Output:
% Cm     Coefficient for all TE slit modes
%
function Cm=slitCte(g0,gm,k0,wx)
t=max(50,5*length(gm));
s=wx/2/t;
x=(-t:t)*s;
f=exp(i*k0*g0*x);
Cm=f*sin(k0*(x'+wx/2)*gm)/t;
%
%Total relative intensity mismatch Ptot
%
d=f-Cm*sin(k0*gm'*(x+wx/2));
fprintf('Total relative intensity mismatch Ptot = %g%%\n',100*(d*d')/(f*f'));
