%contour3Dprint(r, N)
%--------------------
%
%Draws the intensity profile at the xy, xz and yz cross-sections.
%
%Input:
% r      Structure (see 'holeField')
% N      Number of xy-slices {1}
%
function contour3Dprint(r, N)
if nargin < 2 | isempty(N)
   N=1;
end
u=find(r.x >= 0);
v=find(r.y >= 0);
w=find(r.z >= r.h);
%
%Scale 1. quadrant
%
x=r.x(u)*1e9;
y=r.y(v)*1e9;
z=r.z(w)*1e9;
I=double(r.I(u,v,w));
L=max(I(:))*exp(-0.5:-0.5:-6);
[u,v,w]=size(I);
%
%Create figure
%
f.Parent=figure('Color',[1 1 1],'Colormap',repmat(1/255*(255:-1:0)',1,3),'Name','Intensity profile','NumberTitle','off','Toolbar','none');
a.Parent=axes(f,'DataAspectRatio',[1 1 1],'Position',[0.12 0.05 0.85 0.93],'XLim',[x(1) x(u)],'YLim',[y(1) y(v)],'ZLim',[z(1) z(w)]);
%set([xlabel('x [nm]','Position',[0.9 0 0]);ylabel('y [nm]','Position',[0.2 0 0]);zlabel('z [nm]','Position',[0.1 1 0])],a,'Units','Normalized');
t.HorizontalAlignment='center';
t.VerticalAlignment='middle';
t.Units='Normalized';
text(0.9,-0.02,'x [nm]',t);
text(0.1,-0.02,'y [nm]',t);
text(-0.07,0.98,'z [nm]',t);
view(125,35-5*N);
%
%xy sections
%
P=zeros(u,v);
for h=1:ceil(w/N):w
   P(:,:)=I(:,:,h);
   surface(repmat(x',1,v),repmat(y,u,1),repmat(z(h),u,v),P,'EdgeColor','none',a);
   c=contourc(y,x,P,L);
   while ~isempty(c)
      m=c(2,1);
      n=2:m+1;
      line(c(2,n),c(1,n),repmat(z(h),1,m),lineStyle(c(1,1),L),a);
      c=c(:,2+m:size(c,2));
   end
end
%
%xz section
%
P=zeros(u,w);
P(:,:)=I(:,1,:);
surface(repmat(x',1,w),repmat(y(1),u,w),repmat(z,u,1),P,'EdgeColor','none',a);
c=contourc(z,x,P,L);
while ~isempty(c)
   m=c(2,1);
   n=2:m+1;
   line(c(2,n),repmat(y(1),1,m),c(1,n),lineStyle(c(1,1),L),a);
   c=c(:,2+m:size(c,2));
end
%
%yz section
%
P=zeros(v,w);
P(:,:)=I(1,:,:);
surface(repmat(x(1),v,w),repmat(y',1,w),repmat(z,v,1),P,'EdgeColor','none',a);
c=contourc(z,y,P,L);
while ~isempty(c)
   m=c(2,1);
   n=2:m+1;
   line(repmat(x(1),1,m),c(2,n),c(1,n),lineStyle(c(1,1),L),a);
   c=c(:,2+m:size(c,2));
end
%
%Enforce coordinate axes
%
a.Color=[0 0 0];
line(x([1 1]),y([1 1]),z([1 w]),a);
line(x([u 1 1 1 1 u]),y([1 1 v v 1 1]),z([1 1 1 w w w]),a);
for h=1+ceil(w/N):ceil(w/N):w;
   line(x([1 1 u u 1]),y([v 1 1 v v]),repmat(z(h),1,5),a);
end


function o=lineStyle(I, L)
m=find(L == I);
c=[0 0.1 0.2];
s={'-','--',':'};
o.LineStyle=s{ceil(m/4)};
o.Color=repmat(c(ceil(m/4)),1,3);
