%s=lensPupil(s)
%--------------
%
%Input:
% s      Data structure
%  .e       Relative dielectric constant
%  .l       Wavelength in free space [m]
%  .d       Lens diameter [m]
%  .f       Back focal length [m]
%  .p       Period of lens array [m]
%
%Output:
% s      Modified data structure
%  .k       Wavevector [rad/m]
%  .c       Full coordinates [m]
%  .i       Pupil region indexes
%  .x       Pupil coordinates [m]
%  .y
%  .r
%  .Ex      Electric field coefficients [V/m]
%  .Ey
%  .Ez
%  .Tp      Phase and apodisation
%
function s=lensPupil(s)
s.k=2*pi*sqrt(s.e)/s.l;
%
%Sampling
%
t=s.l*sqrt((s.f/s.d)^2+0.25);
n=2^ceil(log2(s.p/2/t));
t=s.p/n;
%
%Pupil coordinates
%
s.c=((0.5:n)-n/2)'*t;
t=repmat(s.c.^2,1,n);
R=t+t';
s.i=int32(find(R <= s.d^2/4));
R=R(s.i);
s.r=sqrt(R);
s.c=single(s.c);
t=repmat(s.c,1,n);
s.x=t(s.i);
t=t';
s.y=t(s.i);
%
%Intermediate constants
%
fr=sqrt(s.f^2+R);
cT=s.f./fr;
ct=s.r == 0;
cP=(double(s.x)+ct)./(s.r+ct);
sP=double(s.y)./(s.r+ct);
ct=cT-1;
%
%Transmission coefficients
%
s.Ex=single(ct.*cP.*sP);
s.Ey=single(ct.*sP.^2+1);
s.Ez=single(s.r./fr.*sP);
%
%Phase and apodisation
%
s.Tp=single(sqrt(cT).*(s.r < s.d/2).*exp(i*s.k*(fr-s.f)));
s.r=single(s.r);
