%[gx,gy,Fn]=fourierCte(C0,g0,Cm,gm,k0,wx,wy,px,py,P)
%---------------------------------------------------
%
%Computes the field difference at the hole boundary and
%returns the coefficients of the Fourier expansion in x
%and y.
%
%Input:
% C0     Coefficient at the metal layer
% g0     kx/k0 of the incident wave
% Cm     Modal coefficients at the hole
% gm     kx/k0 of the TE hole modes
% k0     Wavevector in free space [rad/m]
% wx     Width of the holes [m]
% wy
% px     Distance between the holes [m]
% py
% P      Compute up to |kx|=P*k0 {all}
%
%Output:
% gx     kx/k0 of the diffracted waves
% gy
% Fn     Fourier coefficients
%
function [gx,gy,Fn]=fourierCte(C0,g0,Cm,gm,k0,wx,wy,px,py,P)
t=max(100,10*length(gm));
t=2^ceil(log2(px/wx*t));
s=floor(t*wx/2/px);
x=px/t*(-s:s);
f=Cm*sin(k0*gm'*(x+wx/2))-C0*exp(i*k0*g0*x);
n=(-t/2:t/2-1);
gx=n*2*pi/px/k0;
Fx=fftshift(fft(f,t)/t);
gy=n*2*pi/py/k0;
Fy=wy/py*sinc(wy/py*n);
if length(P)
   t=find(abs(gx) < P);
   gx=gx(t);
   Fx=Fx(t);
   t=find(abs(gy) < P);
   gy=gy(t);
   Fy=Fy(t);
end
gx=gx';
Fn=Fx.'*Fy;
t=size(gx);
gx=repmat(gx,size(gy));
gy=repmat(gy,t);
if length(P)
   t=find(gx.^2+gy.^2 < P^2);
   gx=gx(t);
   gy=gy(t);
   Fn=Fn(t);
else
   gx=gx(:);
   gy=gy(:);
   Fn=Fn(:);
end
