%[bx,by,bz]=projectEy(gx,gy,e)
%-----------------------------
%
%Projects the electric field component Ei // y-axis on a
%vector transverse to the wavevector k (// propagation).
%
%Input:
% gx     kx/k0 of the propagation directions
% gy
% e      Relative dielectric constant
%
%Output:
% bx     Projection factors so that Ex = bx*Ei
% by
% bz
%
function [bx,by,bz]=projectEy(gx,gy,e)
%
%Surface plasmons have imaginary betas
%
bn=real(sqrt(real(sqrt(e))^2-gx.^2-gy.^2));
%
%Normalize the truncated k-vectors
%
t=sqrt(gx.^2+gy.^2+bn.^2);
gx=gx./t;
gy=gy./t;
bn=bn./t;
%
%Projection coefficients
%
by=bn.^2+gx.^2;
bx=-gx.*gy.*by;
bz=-bn.*gy.*by;
by=by.*by;
