%[f,P]=spectrum3D(r, t, a)
%-------------------------
%
%Displays the reflection or transmission spectrum.
%
%Input:
% r     Data structure (see 'holeFieldTE')
% t     Spectrum type 'reflection' or {'transmission'}
% a     NA limit for the spectrum {all}
%
%Output:
% f     Figure handle
% P     Optical power in the spectrum [W]
%
function [f,P]=spectrum3D(r, t, a)
if nargin < 2 | ~strcmp(t,'reflection')
   t='t';
   n='Transmiss';
else
   t='r';
   n='Reflect';
end
F=getfield(r,['F' t]);
g=getfield(r,['g' t]);
if nargin == 3 & ~isempty(a)
   f=find(abs(g) <= a);
   g=g(f);
   F=F(f);
   a=[-a a];
else
   a=[];
end
if nargout == 2
   if t == 't'
      P=sum(F.*real(zSpeed(r.e4,real(g),imag(g))/sqrt(r.e4)))*r.px*r.py;
   else
      P=sum(F.*real(zSpeed(r.e1,real(g),imag(g))/sqrt(r.e1)))*r.px*r.py;
   end
end
f=figure('NumberTitle','off','Name',[n 'ion spectrum']);
trisurf(delaunay(real(g),imag(g)),real(g),imag(g),F,'Parent',axes('Parent',f),'EdgeColor','none','FaceColor','interp','FaceLighting','phong');
if ~isempty(a)
   set(gca,'XLim',a,'YLim',a);
end
xlabel('\gamma_x = n sin(\theta_x)');
ylabel('\gamma_y = n sin(\theta_y)');
zlabel('I [W/m^2]');
view(35,45);
camlight;
grid on;
