%f=volume3D(r, p)
%----------------
%
%Displays the volume inside where the intensity is higher
%than p times the peak intensity in region IV.
%
%Input:
% r     Data structure (see 'holeFieldTE')
% p     Intensity ratio for the isosurface {exp(-2)}
%
%Output:
% f     Figure handle
%
function f=volume3D(r, p)
if nargin < 2 | isempty(p)
    p=exp(-2);
end
m=find(r.z >= r.h);
[X,Y,Z]=meshgrid(r.x*1e9,r.y*1e9,r.z(m)*1e9);
I=double(permute(real(r.I(:,:,m)),[2 1 3]));
f=figure('NumberTitle','off','Name',sprintf('%d%% intensity surface',round(100*p(1))));
a=axes('Parent',f,'XLim',[r.x(1) r.x(length(r.x))]*1e9,'YLim',[r.y(1) r.y(length(r.y))]*1e9,'ZLim',[r.h r.z(length(r.z))]*1e9);
while length(p)
   isonormals(X,Y,Z,I,patch(isosurface(X,Y,Z,I,max(max(max(I)))*p(1)),'EdgeColor','none','FaceAlpha',1/length(p),'FaceColor','red','Parent',a));
   p=p(2:length(p));
end
daspect([1 1 1]);
lighting phong;
view(35,45);
camlight;
grid on;
