%r=chargeDensity(r)
%------------------
%
%Charge density induced by the electromagnetic field.
%
%Input:
% r      Structure (see 'holeField')
%
%Output:
% r      Structure completed with
%  .r       Electronic charge density [Q/m^3]
%
function r=chargeDensity(r)
%
%Charge density
%
% r = div(e0*real(er)*E)
%
m=epsilon(r,inline('8.85418782e-12*real(x)'));
if isfield(r,'Ex')
   Dx=m.*double(r.Ex);
else
   Dx=zeros(r.W);
end
if isfield(r,'Ey')
   Dy=m.*double(r.Ey);
else
   Dy=zeros(r.W);
end
if isfield(r,'Ez')
   Dz=m.*double(r.Ez);
else
   Dz=zeros(r.W);
end
clear m;
r.r=single(div(Dx,Dy,Dz,r.x,r.y,r.z));
