%display3D(r, F)
%---------------
%
%Displays the electromagnetic field through an array of metallic holes.
%
%Input:
% r      Structure (see 'holeField')
% F      Field to display
%
function display3D(r, F)
if nargin < 2 | isempty(F) | ~isfield(r,F)
   F=[];
   s={'Ey','Hy','Ex','Hx','Ez','Hz'};
   for j=1:length(s)
      if isfield(r,s{j})
         F=s{j};
         break;
      end
   end
end
if isempty(F) | ~isfield(r,F)
   disp(['There is no ' F ' field to display.']);
   return;
end
r.F=F;
%
%Reduce memory consumption
%
s={'I','Ex','Ey','Ez','Hx','Hy','Hz'};
for n=1:length(s)
   if isfield(r,s{n})
      setfield(r,s{n},single(getfield(r,s{n})));
   end
end
%
%Display an xz, xy or yz section.
%
t=find(r.W > 1);
r.V=[t(1) t(length(t))];
%
%Display a centered section
%
t=r.W;
t(r.V)=1;
r.U=ceil(prod(t)/2);
%
%Precompute maximal intensity and field strength
%
s=double(r.I(:));
r.M=max(s(find(isfinite(s))));
r.N=max(real(sqrt([r.e1 r.e2 r.e3 r.e4])));
%
%Creates the display and its controls window.
%
h=createDisplay3D(r);
s=get(0,'ScreenSize');
set(h,'Position',[(s(3:4)-r.W(r.V))/2 r.W(r.V)]);
updateControls3D(h);
updateDisplay3D(h);
