%r=electricField(r)
%------------------
%
%Derives the electric from the magnetic field.
%
%Input:
% r      Structure (see 'holeField')
%
%Output:
% r      Structure completed with
%  .Ex      Electric field [V/m]
%  .Ey
%  .Ez
%
function r=electricField(r)
if ~nargin | ~isstruct(r)
   help electricField
   return;
end
%
%Electric field
%
% E = rot(H)*sqrt(u0/e0)/(i*k0*er)
%
if isfield(r,'Hx')
   u=r.Hx;
else
   u=zeros(r.W);
end
if isfield(r,'Hy')
   v=r.Hy;
else
   v=zeros(r.W);
end
if isfield(r,'Hz')
   w=r.Hz;
else
   w=zeros(r.W);
end
e0=8.85418782e-12; % [As/Vm]
u0=1.25663706e-6;  % [Vs/Am]
m=sqrt(u0/e0)/(i*r.k0)*epsilon(r,inline('1/x'));
[u,v,w]=rot(u,v,w,r.x,r.y,r.z);
if isnonzero(u)
   r.Ex=single(m.*u); clear u;
end
if isnonzero(v)
   r.Ey=single(m.*v); clear v;
end
if isnonzero(w)
   r.Ez=single(m.*w); clear w;
end


function b=isnonzero(m)
b=sum(sum(sum(m ~= 0)));
