%r=electricIntensity(r)
%----------------------
%
%Electromagnetic intensity.
%
%Input:
% r      Structure (see 'holeField')
%
%Output:
% r      Structure with refreshed
%  .I       Intensity [W/m^2]
%
function r=electricIntensity(r)
if ~nargin | ~isstruct(r)
   help electricIntensity
   return;
end
%
%Intensity
%
% I = 1/2*real(E*conj(E)*sqrt(e0*er/u0))
%
e0=8.85418782e-12; % [As/Vm]
u0=1.25663706e-6;  % [Vs/Am]
if isfield(r,'Ex')
   r.I=double(r.Ex).*conj(double(r.Ex));
else
   r.I=zeros(r.W);
end
if isfield(r,'Ey')
   r.I=r.I+double(r.Ey).*conj(double(r.Ey));
end
if isfield(r,'Ez')
   r.I=r.I+double(r.Ez).*conj(double(r.Ez));
end
r.I=single(sqrt(e0/u0)/2*real(epsilon(r,inline('sqrt(x)')).*r.I));
