%r=electricPotential(r, t)
%-------------------------
%
%Computes the electric potential.
%
%Input:
% r      Structure (see 'slitField')
% t      Tolerance {1e-8}
%
%Output:
% r      Structure completed with
%  .U       Electric potential [V]
%
function r=electricPotential(r, t)
if ~nargin | ~isstruct(r)
   help electricPotential
   return;
end
if nargin < 2 | isempty(t)
   t=1e-8;
else
   t=abs(t(1));
end
set(updateStatus(0),'Name','Electric potential');
p=r.S./r.W;
a=[1 1 1]/3;
b=[1 0 -1]/3;
if isfield(r,'Ex')
   g=conv3(b,a,a,p(1)*double(r.Ex));
else
   g=zeros(r.W);
end
if isfield(r,'Ey')
   g=g+conv3(a,b,a,p(2)*double(r.Ey));
end
if isfield(r,'Ez')
   g=g+conv3(a,a,b,p(3)*double(r.Ez));
end
[p,i]=sort(-r.W);
g=permute(g,i);   % 'conv2' is faster than 'convn'
m=-p(1);
n=-p(2);
o=-p(3);
d=1;
p=g;
while d > t;
   updateStatus(sqrt(t/d));
   for b=1:16
      p=iteration(a,p,g,m,n,o);
   end
   d=p(:);
   p=iteration(a,p,g,m,n,o);
   e=p(:);
   d=d-e;
   d=sum(real(d).^2 + imag(d).^2)/sum(real(e).^2 + imag(e).^2);
end
r.U=ipermute(single(p),i);
delete(updateStatus(1));


function p=iteration(a,p,g,m,n,o)
p=conv3(a,a,a,p)+g;
p(1,:,:)=1.5*p(1,:,:);
p(m,:,:)=1.5*p(m,:,:);
if n > 1
   p(:,1,:)=1.5*p(:,1,:);
   p(:,n,:)=1.5*p(:,n,:);
else
   p(:,1,:)=3*p(:,1,:);
end
if o > 1
   p(:,:,1)=1.5*p(:,:,1);
   p(:,:,o)=1.5*p(:,:,o);
else
   p(:,:,1)=3*p(:,:,1);
end
