%[R13,T13,A2,B2]=layerRT(R12,T12,R23,T23,g0,k0,e2,h2)
%----------------------------------------------------
%
%Computes the Fresnel reflection and transmission coefficients
%for a plane wave traveling through a multiple layers.
%
%Input:
% R12    Reflection coefficients
% R23
% T12    Transmission coefficients
% T23
% g0     kx/k0 of the incident wave
% k0     Wavevector in free space [rad/m]
% e2     Relative dielectric constant
% h2     Thickness of the layer [m]
%
%Output:
% R13    Reflection coefficient at the layer
% T13    Transmission coefficient through the layer
% A2     Coefficient of the propagating wave in the layer
% B2     Coefficient of the withdrawing wave in the layer
%
function [R13,T13,A2,B2]=layerRT(R12,T12,R23,T23,g0,k0,e2,h2)
a=exp(i*k0*h2*sqrt(e2-g0.^2));
b=1+R12.*R23.*a.*a;
A2=T12./b;
B2=R23.*A2.*a.*a;
R13=(R12+R23.*a.^2)./b;
T13=T23.*A2.*a;
