%[R13,T13,A2,B2]=layerRTte(e1,e2,e3,g,k0,h2)
%-------------------------------------------
%
%Computes the Fresnel reflection and transmission coefficients
%for a plane TE wave traveling through a thin layer.
%
%Input:
% e1     Relative dielectric constants
% e2
% e3
% g      kx/k0 of the incident wave
% k0     Wavevector in free space [rad/m]
% h2     Thickness of the inner layer [m]
%
%Output:
% R13    Reflection coefficient at the layer
% T13    Transmission coefficient through the layer
% A2     Coefficient of the propagating wave in the layer
% B2     Coefficient of the withdrawing wave in the layer
%
function [R13,T13,A2,B2]=layerRTte(e1,e2,e3,g,k0,h2)
[R12,T12]=surfaceRTte(e1,e2,g);
[R23,T23]=surfaceRTte(e2,e3,g);
a=exp(i*h2*k0.*sqrt(e2-g.^2));
b=1+R12.*R23.*a.^2;
A2=T12./b;
B2=R23.*A2.*a.^2;
R13=(R12+R23.*a.^2)./b;
T13=T23.*A2.*a;
