%e=localReh(x,e1,e3,k0,gf,gm,Rm)
%-------------------------------
%
%Squaresum of difference between fit and measured reflection in a
%Kretschmann setup. Collimated, monochromatic light is incident on
%a thin metal film at TM polarisation. The metal film is deposited
%on a sample holder - in general a glass semi-cylinder. The reflection
%efficiency Rm=Ir/Ii is measured at various incidence angles tm.
%
%Input:
% x      Fitting parameters [e2;h2]
% e1     Dielectric constant of the sample holder
% e3     Dielectric constant behind the film
% k0     Wavevector in free space [rad/m]
% gf     Incident angles of flat
% gm     Incidence angles kx/k0 > 1
% Rm     Measured reflection efficiencies
%
%Output:
% e      Error between Rm and theoretical reflectance
%
function e=localReh(x,e1,e3,k0,gf,gm,Rm)
Rt=layerRTtm(e1,x(1),e3,gm,k0,x(2));
Rf=layerRTtm(e1,x(1),e3,gf,k0,x(2));
Rt=Rt.*conj(Rt)/mean(Rf.*conj(Rf));
e=sum((Rm-real(Rt)).^2);
