%r=magneticField(r)
%------------------
%
%Derives the magnetic from the electric field.
%
%Input:
% r      Structure (see 'holeField')
%
%Output:
% r      Structure completed with
%  .Hx      Magnetic field [A/m]
%  .Hy
%  .Hz
%
function r=magneticField(r)
if ~nargin | ~isstruct(r)
   help magneticField
   return;
end
%
%Magnetic field
%
% H = rot(E)*sqrt(e0/u0)*i/k0
%
if isfield(r,'Ex')
   u=r.Ex;
else
   u=zeros(r.W);
end
if isfield(r,'Ey')
   v=r.Ey;
else
   v=zeros(r.W);
end
if isfield(r,'Ez')
   w=r.Ez;
else
   w=zeros(r.W);
end
e0=8.85418782e-12; % [As/Vm]
u0=1.25663706e-6;  % [Vs/Am]
m=sqrt(e0/u0)*i/r.k0;
[u,v,w]=rot(u,v,w,r.x,r.y,r.z);
if isnonzero(u)
   r.Hx=single(m*u); clear u;
end
if isnonzero(v)
   r.Hy=single(m*v); clear v;
end
if isnonzero(w)
   r.Hz=single(m*w); clear w;
end


function b=isnonzero(m)
b=sum(sum(sum(m ~= 0)));
