%r=magneticIntensity(r)
%----------------------
%
%Electromagnetic intensity.
%
%Input:
% r      Structure (see 'holeField')
%
%Output:
% r      Structure with refreshed
%  .I       Intensity [W/m^2]
%
function r=magneticIntensity(r)
if ~nargin | ~isstruct(r)
   help magneticIntensity
   return;
end
%
%Intensity
%
% I = 1/2*real(H*conj(H)*sqrt(u0/e0*er))
%
e0=8.85418782e-12; % [As/Vm]
u0=1.25663706e-6;  % [Vs/Am]
if isfield(r,'Hx')
   r.I=double(r.Hx).*conj(double(r.Hx));
else
   r.I=zeros(r.W);
end
if isfield(r,'Hy')
   r.I=r.I+double(r.Hy).*conj(double(r.Hy));
end
if isfield(r,'Hz')
   r.I=r.I+double(r.Hz).*conj(double(r.Hz));
end
r.I=single(sqrt(u0/e0)/2*real(epsilon(r,inline('1/sqrt(x)')).*r.I));
