%r=matchIntensity(r)
%-------------------
%
%Equalizes the intensity maxima of the input and the
%output region. If the input region is not visible,
%the structured metal layer is taken as reference.
%
%Input:
% r      Structure (see 'holeField')
%
%Output:
% r      Structure
%  .I       Intensity with boosted output [W/m^2]
%
function r=matchIntensity(r)
[a,b]=regions(r);
h=r.W(3);
if b == h
   return;
end
if a == 1
   a=b;
else
   a=a-1;
end
b=b+1;
I=double(r.I);
mi=max(max(max(I(:,:,1:a))));
mo=max(max(max(I(:,:,b:h))));
if mi > mo
   fprintf('Transmitted intensity multiplied by %8.3g.\n',mi/mo);
   r.I(:,:,b:h)=single(mi/mo*I(:,:,b:h));
else
   fprintf('Reflected intensity multiplied by %8.3g.\n',mo/mi);
   r.I(:,:,1:a)=single(mo/mi*I(:,:,1:a));
end
