%f=derive(f, d, p)
%-----------------
%
%Approximate derivative.
%
%Input:
% f      Scalar field
% d      Derivate along this dimension {first non-singleton}
% p      Coordinate along the dimension (must be monotonic)
%
%Output:
% f      Derivation: df/dp
%
function f=derive(f, d, p)
s=size(f);
if nargin < 2 | isempty(d)
   d=find(s > 1);
   if isempty(d)
      f=zeros(s);
      return;
   end
end
d=d(1);
n=s(d);
if n <= 1
   f=zeros(s);
   return;
end
if nargin < 3 | isempty(p)
   p=[1;0.5*ones(n-2,1);1];
else
   p=double(p(:));
   p=1./[p(2)-p(1);p(3:n)-p(1:n-2);p(n)-p(n-1)];
end
d=[d 1:d-1 1+d:ndims(f)];
f=double(permute(f,d));
%
%Forward differences at the edges, centered differences in the interior
%
s=[1 prod(s(d(2:length(d))))];
f(:,:)=[f(2,:)-f(1,:);f(3:n,:)-f(1:n-2,:);f(n,:)-f(n-1,:)].*repmat(p,s);
f=ipermute(f,d);
