%[a,b,c]=rot(u,v,w, x,y,z)
%-------------------------
%
%Curl of a vector field.
%
%Input:
% u/v/w  Components of the vector field
% x/y/z  Coordinates (must be monotonic)
%
%Output:
% a/b/c  Curl:
%           a = dv/dz - dw/dy
%           b = dw/dx - du/dz
%           c = du/dy - dv/dx
%
function [a,b,c]=rot(u,v,w, x,y,z)
switch nargin
case 2
   a=derive(u,2)-derive(v,1);
   return;
case 3
   x=[];
   y=[];
   z=[];
case 4
   a=derive(u,2,x)-derive(v,1,w);
   return;
case 6
otherwise
   error('Wrong number of parameters.');
end
[t,c,u]=grad(double(u),x,y,z);
[v,t,a]=grad(double(v),x,y,z);
[b,w,t]=grad(double(w),x,y,z);
a=a-w;
b=b-u;
c=c-v;
