%[R12,T12]=surfaceRTte(e1,e2,g)
%------------------------------
%
%Computes the Fresnel reflection and transmission coefficients
%for a plane TE wave impinging onto a material boundary.
%
%Input:
% e1     Relative dielectric constants
% e2
% g      kx/k0 of the incident wave
%
%Output:
% R12    Reflection coefficient at the boundary
% T12    Transmission coefficient through the boundary
%
function [R12,T12]=surfaceRTte(e1,e2,g)
%a=sqrt(e1-g.^2);
%b=sqrt(e2-g.^2);
a=zSpeed(e1,g);
b=zSpeed(e2,g);
c=a-b;
d=a+b;
n=find(c ~= d);
R12=ones(size(c));
R12(n)=c(n)./d(n);
T12=R12+1;
