%f=updateControls3D(h)
%---------------------
%
%Updates the 3D display controls to reflect the active figure.
%
%Input:
% h      The window handle that is active.
%
%Output:
% f      The controls' window handle.
%
function f=updateControls3D(h)
f=createControls3D;
s='holeDisplay3D';
u='UserData';
t='Tag';
if nargin & ishandle(h) & strcmp(get(h,t),s)
   set(f,u,h);
else
   h=get(f,u);
   if isempty(h) | ~ishandle(h)
      h=findobj(get(0,'Children'),'flat',t,s);
      if isempty(h)
         delete(f);
         return;
      end
      h=h(1);
      set(f,u,h);
   end
end
%
%Enable the controls
%
set(findobj(get(f,'Children'),'flat','Enable','off'),'Enable','on');
a=get(f,'CurrentAxes');
r=get(h,'UserData');
%
%Update the field components list
%
j=[];
s=fieldnames(r);
for n=1:length(s)
   switch s{n}
   case {'Ex','Ey','Ez','Hx','Hy','Hz'}
      j=[j n];
   end
end
s=s(j);
for n=1:length(s)
   if strcmp(s{n},r.F)
      j=n;
      break;
   end
end
set(getControl(f,'List'),'String',s,'Value',j);
%
%Update the axes view list
%
j=1;
switch sum(find(r.W > 1))
case 3
   s={'xy'};
case 4
   s={'xz'};
case 5
   s={'yz'};
case 6
   s={'xy','xz','yz'};
   j=sum(r.V)-2;
otherwise
   s=' ';
end
set(getControl(f,'View'),'String',s,'Value',j);
%
%Update the slider and its text
%
updateSlider(f,r);
%
%Update the scheme
%
%delete(get(a,'Children'));
%t=[-10 10];
%c=[0 0 0];
%x=zeros(2,3);
%y=[0 9 9;10 10 10];
%z=[0 -0.3 0.3;0 0 0];
%line([x y z],[y z x],[z x y],'Color',c,'Parent',a);
%set(a,'Visible','off','XDir','reverse','XLim',t,'YLim',t,'ZDir','reverse','ZLim',t,'CameraPosition',[5 15 -5],'CameraTarget',[0 0 0]);
%set(a,'Visible','off','XDir','reverse','ZDir','reverse','CameraPosition',[2 5 -1],'CameraTarget',[0 0 0]);
