%updateDisplay3D(h)
%------------------
%
%Updates a 3D display window.
%
%Input:
% h      Handle of the 3D display window.
%
function updateDisplay3D(h)
a=get(h,'CurrentAxes');
feval(get(a,'Tag'),h,a,get(h,'UserData'));

%
%Extracts a section of the electormagnetic field
%
function [x,y,F]=getSection(r,f)
s={'x','y','z'};
x=getfield(r,s{r.V(1)});
y=getfield(r,s{r.V(2)});
F=zeros(r.W(r.V));
switch sum(r.V)
case 3
   F(:,:)=f(:,:,r.U);
case 4
   F(:,:)=f(:,r.U,:);
case 5
   F(:,:)=f(r.U,:,:);
end
y=fliplr(y);
F=double(F.');

%
%Displays the electromagnetic field strength
%
function Field(h,a,r)
if ~isfield(r,'wt')
   r.wt=0;
   set(h,'UserData',r);
end
t=zeros(256,3);
t(1:128,3)=(255:-2:1)'/255;
t(129:256,1)=(1:2:255)'/255;
set(h,'Colormap',t);
Frame(a,r);

%
%Animates the electromagnetic field
%
function Start(h,a,r)
s=cputime;
for l=1:72
   s=s+0.2;
   r.wt=r.wt+pi/18i;
   set(h,'UserData',r);
   Frame(a,r);
   drawnow;
   if cputime < s
      pause(s-cputime);
   end
   if ~ishandle(h) | ~strcmp(get(a,'Tag'),'Start')
      return;
   end
   r=get(h,'UserData');
end
set(a,'Tag','Field');

%
%Displays the field component
%
function Frame(a,r)
[x,y,F]=getSection(r,getfield(r,r.F));
e0=8.85418782e-12; % [As/Vm]
u0=1.25663706e-6;  % [Vs/Am]
if r.F(1) == 'E'
   t=127.5/sqrt(2*r.M*sqrt(u0/e0)/r.N);
else
   t=127.5/sqrt(2*r.M*sqrt(e0/u0)*r.N);
end
image(x,y,uint8(127.5+real(t*exp(r.wt)*F)),'Parent',a);

%
%Displays the electromagnetic field intensity
%
function Intensity(h,a,r)
[x,y,I]=getSection(r,r.I);
set(h,'Colormap',repmat((0:255)'/255,1,3));
image(x,y,uint8(I*255/r.M),'Parent',a);

%
%Displays the electromagnetic field phase
%
function Phase(h,a,r)
[x,y,F]=getSection(r,getfield(r,r.F));
set(h,'Colormap',repmat((0:255)'/255,1,3));
image(x,y,uint8((angle(F)+pi)*127.5/pi),'Parent',a);
