%[g,t]=stepCorrelation(s)
%------------------------
%
%Autocorrelation of the signal s in a quasi-logarithmic
%scale for time shifts t <= length(s)/2.
%
%Input:
% s     Signal vector
%
%Output:
% g     Normalised autocorrelation g(t)
% t     Corresponding time shifts
%
function [r,g,t]=stepCorrelation(s)
r=create(16);
for n=1:length(s)
   r=iterate(r,s(n));
end
r=result(r);
g=r.g;
t=r.t;


function r=create(N)
r.n=0;
r.N=N;
r.L=zeros(1,N);
r.G=zeros(1,N);
r.S=zeros(1,N);
r.T=0;

function r=iterate(r,I)
r.n=r.n+1;
r.G=r.G+I*r.L;
r.L=[I r.L(1:r.N-1)];
if r.n <= r.N
   r.S(r.n)=I;
end
r.T=r.T+I;
return;
if ~mod(r.n,2)
   if r.n == 2
      r.r=create(r.N);
   end
   r.r=iterate(r.r,r.L(1)+r.L(2));
end

function r=result(r)
r.t=1:r.N;
r.g=r.G./(r.n-r.t);
T=2*r.T;
for n=r.t
   T=T-r.L(n)-r.S(n);
   if T
      r.g(n)=4*(r.n-n)*r.G(n)/T^2;
   end
end
return;
if r.n > r.N
   r.r=result(r.r);
   m=2*(1:length(r.r.t)) > r.N;
   r.t=[r.t 2*r.r.t(m)];
   r.g=[r.g r.r.g(m)];
end
